@@ -5,6 +5,7 @@
 #' @inheritParams ggplot2::scale_discrete_manual
 #' @inheritDotParams ggplot2::discrete_scale -expand -position -palette -breaks
 #' @importFrom ggplot2 discrete_scale
+#' @importFrom cli cli_abort
 #' @rdname scale_geo
 #' @param dat Either A) a string indicating a built-in dataframe with interval
 #'   data from the ICS ("periods", "epochs", "stages", "eons", or "eras"),
@@ -15,21 +16,23 @@
 #' @export
 #' @examples
 #' library(ggplot2)
-#' df <- data.frame(x = runif(1000, 0, 10), y = runif(1000, 0, 10),
-#'                  color = sample(periods$name, 1000, TRUE), shape = 21)
+#' df <- data.frame(
+#'   x = runif(1000, 0, 10), y = runif(1000, 0, 10),
+#'   color = sample(periods$name, 1000, TRUE), shape = 21
+#' )
 #' ggplot(df) +
 #'   geom_point(aes(x = x, y = y, fill = color), shape = 21) +
 #'   scale_fill_geo("periods", name = "Period") +
 #'   theme_classic()
 #'
 #' # cut continuous variable into discrete
-#' df <-data.frame(x = runif(1000, 0, 1000), y = runif(1000, 0, 8))
+#' df <- data.frame(x = runif(1000, 0, 1000), y = runif(1000, 0, 8))
 #' df$color <- cut(df$x, c(periods$min_age, periods$max_age[22]), periods$name)
 #' ggplot(df) +
 #'   geom_point(aes(x = x, y = y, color = color)) +
 #'   scale_x_reverse() +
 #'   scale_color_geo("periods", name = "Period") +
-#'   coord_geo(xlim = c(1000, 0), ylim = c(0,8)) +
+#'   coord_geo(xlim = c(1000, 0), ylim = c(0, 8)) +
 #'   theme_classic()
 scale_color_geo <- function(dat, ...) {
   scale_discrete_geo(dat, "color", ...)
@@ -49,9 +52,9 @@ scale_fill_geo <- function(dat, ...) {
 #' @export
 #' @rdname scale_geo
 scale_discrete_geo <- function(dat, aesthetics, ...) {
-  if(is(dat, "data.frame")){
-    #just use the supplied data
-  }else{
+  if (is(dat, "data.frame")) {
+    # just use the supplied data
+  } else {
     dat <- get_scale_data(dat)
   }
   if (!all(c("name", "color") %in% colnames(dat))) {
@@ -61,8 +64,8 @@ scale_discrete_geo <- function(dat, aesthetics, ...) {
 
   pal <- function(n) {
     if (n > length(values)) {
-      cli::cli_abort("Insufficient values in manual scale. {n} needed but only
-                     {length(values)} provided.")
+      cli_abort("Insufficient values in manual scale. {n} needed but only
+                {length(values)} provided.")
     }
     values
   }
